==> dokuwiki_0.0.20110525a.orig.tar.gz: dokuwiki-2011-05-25a/lib/plugins/plugin/lang/eu/lang.php <==
<?php
/**
 * Basque language file
 *
 * @author Inko Illarramendi <inko.i.a@gmail.com>
 */
$lang['menu']                  = 'Plugin-ak Kudeatu';
$lang['download']              = 'Plugin berri bat deskargatu eta instalatu';
$lang['manage']                = 'Instalatutako Plugin-ak';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'eguneratu';
$lang['btn_delete']            = 'ezabatu';
$lang['btn_settings']          = 'ezarpenak';
$lang['btn_download']          = 'Deskargatu';
$lang['btn_enable']            = 'Gorde';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalatua:';
$lang['lastupdate']            = 'Azken aldiz eguneratua:';
$lang['source']                = 'Iturria:';
$lang['unknown']               = 'ezezaguna';
$lang['updating']              = 'Eguneratzen ...';
$lang['updated']               = 'Arrakastaz eguneratu da %s plugin-a';
$lang['updates']               = 'Ondorengo plugin-ak ondo eguneratu dira';
$lang['update_none']           = 'Ez da eguneraketarik aurkitu.';
$lang['deleting']              = 'Ezabatzen ...';
$lang['deleted']               = '%s plugin-a ezabatua.';
$lang['downloading']           = 'Deskargatzen ...';
$lang['downloaded']            = '%s Plugin-a arrakastaz instalatua';
$lang['downloads']             = 'Ondorengo plugin-ak arrakastaz instalatu dira:';
$lang['download_none']         = 'Ez da plugin-ik aurkitu, edo arazo ezezagunen bat egon da deskargatu eta instalatzerako garaian.';
$lang['plugin']                = 'Plugin-a:';
$lang['components']            = 'Osagaiak';
$lang['noinfo']                = 'Plugin honek ez du informaziorik itzuli, agian ez da erabilgarria.';
$lang['name']                  = 'izena:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Mota:';
$lang['desc']                  = 'Deskribapena:';
$lang['author']                = 'Egilea:';
$lang['www']                   = 'Web-gunea:';
$lang['error']                 = 'Akats ezezagun bat gertatu da.';
$lang['error_download']        = 'Ezin izan da plugin-aren honako fitxategia deskargatu: %s';
$lang['error_badurl']          = 'Ustezko url okerra - ezin izan da fitxategi izena url-tik zehaztu';
$lang['error_dircreate']       = 'Ezin izan da aldiroko karpeta sortu deskarga jasotzeko';
$lang['error_decompress']      = 'Plugin kudeatzaileak ezin izan du deskargatutako fitxategia erauzi. Deskarga oker baten ondorioa izan daiteke, eta hala bada berriz saiatu beharko zenuke; edo agian trinkotze formatua ezezaguna da, hala izanik plugin-a eskuz deskargatu eta instalatu beharko zenuelarik.';
$lang['error_copy']            = 'Fitxategi kopia akats bat egon da <em>%s</em> plugin-arentzat fitxategiak instalatzen saiatzean: diska betea egon liteke edo fitxategi atzipen baimena okerra izan daiteke. Honek partzialki instalatutako plugin bat eta wiki instalazioa ezegonkor utzi dezake.';
$lang['error_delete']          = 'Akats bat gertatu da <em>%s</em> plugin-a ezabatzeko saiakera egitean. Arrazoia ziurrenik fitxategi edo direktorio atzipen baimen nahikoak ez izatea da.';
$lang['enabled']               = '%s Plugin-a gaitua.';
$lang['notenabled']            = '%s Plugin-a ezin izan da gaitu, egiaztatu fitxategi baimenak.';
$lang['disabled']              = '%s Plugin-a ezgaitua.';
$lang['notdisabled']           = '%s Plugin-a ezin izan da ezgaitu, egiaztatu fitxategi baimenak. ';
$lang['packageinstalled']      = 'Plugin paketea (%d plugin%s: %s) arrakastaz instalatua izan da.';

==> dokuwiki_0.0.20120125b.orig.tar.gz: dokuwiki-2012-01-25b/lib/plugins/plugin/lang/eu/lang.php <==
<?php
/**
 * Basque language file
 *
 * @author Inko Illarramendi <inko.i.a@gmail.com>
 */
$lang['menu']                  = 'Plugin-ak Kudeatu';
$lang['download']              = 'Plugin berri bat deskargatu eta instalatu';
$lang['manage']                = 'Instalatutako Plugin-ak';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'eguneratu';
$lang['btn_delete']            = 'ezabatu';
$lang['btn_settings']          = 'ezarpenak';
$lang['btn_download']          = 'Deskargatu';
$lang['btn_enable']            = 'Gorde';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalatua:';
$lang['lastupdate']            = 'Azken aldiz eguneratua:';
$lang['source']                = 'Iturria:';
$lang['unknown']               = 'ezezaguna';
$lang['updating']              = 'Eguneratzen ...';
$lang['updated']               = 'Arrakastaz eguneratu da %s plugin-a';
$lang['updates']               = 'Ondorengo plugin-ak ondo eguneratu dira';
$lang['update_none']           = 'Ez da eguneraketarik aurkitu.';
$lang['deleting']              = 'Ezabatzen ...';
$lang['deleted']               = '%s plugin-a ezabatua.';
$lang['downloading']           = 'Deskargatzen ...';
$lang['downloaded']            = '%s Plugin-a arrakastaz instalatua';
$lang['downloads']             = 'Ondorengo plugin-ak arrakastaz instalatu dira:';
$lang['download_none']         = 'Ez da plugin-ik aurkitu, edo arazo ezezagunen bat egon da deskargatu eta instalatzerako garaian.';
$lang['plugin']                = 'Plugin-a:';
$lang['components']            = 'Osagaiak';
$lang['noinfo']                = 'Plugin honek ez du informaziorik itzuli, agian ez da erabilgarria.';
$lang['name']                  = 'izena:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Mota:';
$lang['desc']                  = 'Deskribapena:';
$lang['author']                = 'Egilea:';
$lang['www']                   = 'Web-gunea:';
$lang['error']                 = 'Akats ezezagun bat gertatu da.';
$lang['error_download']        = 'Ezin izan da plugin-aren honako fitxategia deskargatu: %s';
$lang['error_badurl']          = 'Ustezko url okerra - ezin izan da fitxategi izena url-tik zehaztu';
$lang['error_dircreate']       = 'Ezin izan da aldiroko karpeta sortu deskarga jasotzeko';
$lang['error_decompress']      = 'Plugin kudeatzaileak ezin izan du deskargatutako fitxategia erauzi. Deskarga oker baten ondorioa izan daiteke, eta hala bada berriz saiatu beharko zenuke; edo agian trinkotze formatua ezezaguna da, hala izanik plugin-a eskuz deskargatu eta instalatu beharko zenuelarik.';
$lang['error_copy']            = 'Fitxategi kopia akats bat egon da <em>%s</em> plugin-arentzat fitxategiak instalatzen saiatzean: diska betea egon liteke edo fitxategi atzipen baimena okerra izan daiteke. Honek partzialki instalatutako plugin bat eta wiki instalazioa ezegonkor utzi dezake.';
$lang['error_delete']          = 'Akats bat gertatu da <em>%s</em> plugin-a ezabatzeko saiakera egitean. Arrazoia ziurrenik fitxategi edo direktorio atzipen baimen nahikoak ez izatea da.';
$lang['enabled']               = '%s Plugin-a gaitua.';
$lang['notenabled']            = '%s Plugin-a ezin izan da gaitu, egiaztatu fitxategi baimenak.';
$lang['disabled']              = '%s Plugin-a ezgaitua.';
$lang['notdisabled']           = '%s Plugin-a ezin izan da ezgaitu, egiaztatu fitxategi baimenak. ';
$lang['packageinstalled']      = 'Plugin paketea (%d plugin(s): %s) arrakastaz instalatua izan da.';
